(module-name (scheme write))
(require kawa.lib.ports)
(include "write-exports")
